BoolFilters extension

Built in filters for bool columns

on

Methods

isFalse() Expression<bool>

Available on ColumnFilters<bool>, provided by the BoolFilters extension

Create a filter to check if the column is small than a value
isTrue() Expression<bool>

Available on ColumnFilters<bool>, provided by the BoolFilters extension

Create a filter to check if the column is bigger than a value