isFalse method
Create a filter to check if the column is small than a value
Implementation
Expression<bool> isFalse() => $composableFilter(column.equals(false));
Create a filter to check if the column is small than a value
Expression<bool> isFalse() => $composableFilter(column.equals(false));