isTrue method
Create a filter to check if the column is bigger than a value
Implementation
Expression<bool> isTrue() => $composableFilter(column.equals(true));
Create a filter to check if the column is bigger than a value
Expression<bool> isTrue() => $composableFilter(column.equals(true));