isNotNull method
Create a filter that checks if the column is not null.
Implementation
Expression<bool> isNotNull() => $composableFilter(column.isNotNull());
Create a filter that checks if the column is not null.
Expression<bool> isNotNull() => $composableFilter(column.isNotNull());