isBiggerOrEqual method
Returns an expression that is true if this expression is bigger than or equal to he other expression.
Implementation
@pragma('drift:v3-rename', 'isGreaterOrEqual')
Expression<bool> isBiggerOrEqual(Expression<DT> other) {
return _Comparison(this, _ComparisonOperator.moreOrEqual, other);
}