createTypeMapping method
Creates a type mapping suitable for these options and the given dialect.
Implementation
SqlTypes createTypeMapping(SqlDialect dialect) {
return SqlTypes(_storeDateTimeAsText, dialect);
}
Creates a type mapping suitable for these options and the given dialect.
SqlTypes createTypeMapping(SqlDialect dialect) {
return SqlTypes(_storeDateTimeAsText, dialect);
}