asNullable<D, S extends Object, J extends Object> static method
JsonTypeConverter2<D?, S?, J?>
asNullable<D, S extends Object, J extends Object>(
- JsonTypeConverter2<
D, S, J?> inner
Wraps an inner type converter that only considers non-nullable values
as a type converter that handles null values too.
The returned type converter will use the inner type converter for non-
null values. Further, null is mapped to null in both directions (from
Dart to SQL and vice-versa).
Implementation
static JsonTypeConverter2<D?, S?, J?>
asNullable<D, S extends Object, J extends Object>(
JsonTypeConverter2<D, S, J?> inner) {
return _NullWrappingTypeConverterWithJson(inner);
}