isSmallerThan method
Create a filter to check if the column is small than a value
Implementation
Expression<bool> isSmallerThan(T value) =>
$composableFilter(column.isSmallerThanValue(value));
Create a filter to check if the column is small than a value
Expression<bool> isSmallerThan(T value) =>
$composableFilter(column.isSmallerThanValue(value));