driftDatabase function
Implementation
QueryExecutor driftDatabase({
required String name,
bool logsEnabled = false,
}) {
throw UnsupportedError(
'driftDatabase() is not implemented on this platform because neither `dart:ffi` nor ``');
}
QueryExecutor driftDatabase({
required String name,
bool logsEnabled = false,
}) {
throw UnsupportedError(
'driftDatabase() is not implemented on this platform because neither `dart:ffi` nor ``');
}