ToolDatabaseModule class abstract

Inheritance
  • Object
  • BaseModule
  • ToolDatabaseModule

Constructors

ToolDatabaseModule()

Properties

hashCode int
The hash code for this object.
no setterinherited
localizationsDelegate LocalizationsDelegate?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSubscription(StreamSubscription subscription) StreamSubscription
inherited
clear() Future<void>
inherited
dependenciesCreated(GetIt getIt) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSubscription(StreamSubscription subscription) → void
inherited
setupDependencies(GetIt getIt) Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ToolDatabaseModule
no setter

Static Methods

newInstance() ToolDatabaseModule
reset() → void