ToolDatabaseParams class

Constructors

ToolDatabaseParams({required String name, DatabaseConnectMode databaseConnectMode = DatabaseConnectMode.connectInSharedIsolate, bool logsEnabled = false, bool singleClientMode = false})
const

Properties

databaseConnectMode DatabaseConnectMode
final
hashCode int
The hash code for this object.
no setterinherited
logsEnabled bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleClientMode bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited