BigIntFilters<T extends BigInt> extension
Built in filters for BigInt columns
- on
Methods
-
isBetween(
T lower, T higher) → Expression< bool> -
Available on ColumnFilters<
Create a filter to check if the column is between two values This is done inclusively, so the column can be equal to the lower or higher value E.G isBetween(1, 3) will return true for 1, 2, and 3T> , provided by the BigIntFilters extension -
isBiggerOrEqualTo(
T value) → Expression< bool> -
Available on ColumnFilters<
Create a filter to check if the column is bigger or equal to a valueT> , provided by the BigIntFilters extension -
isBiggerThan(
T value) → Expression< bool> -
Available on ColumnFilters<
Create a filter to check if the column is bigger than a valueT> , provided by the BigIntFilters extension -
isSmallerOrEqualTo(
T value) → Expression< bool> -
Available on ColumnFilters<
Create a filter to check if the column is small or equal to a valueT> , provided by the BigIntFilters extension -
isSmallerThan(
T value) → Expression< bool> -
Available on ColumnFilters<
Create a filter to check if the column is small than a valueT> , provided by the BigIntFilters extension