BoolFilters extension
Built in filters for bool columns
- on
Methods
-
isFalse(
) → Expression< bool> -
Available on ColumnFilters<
Create a filter to check if the column is small than a valuebool> , provided by the BoolFilters extension -
isTrue(
) → Expression< bool> -
Available on ColumnFilters<
Create a filter to check if the column is bigger than a valuebool> , provided by the BoolFilters extension