ColumnFilters<T extends Object> constructor
ColumnFilters<T extends Object> (
- Expression<
T> column, { - bool inverted = false,
This class is a wrapper on top of the generated column class
It's used to expose filter functions for a column type
todos.filter((f) => f.name('important'))
In the above example, f.name returns a ColumnFilters object, which
contains methods for creating filters on the name column.
This class is implemented by the code generator and should
not be instantiated or extended manually.
Implementation
ColumnFilters(super.column, {super.inverted = false});