sqlEquals method
Creates a filter that checks whether the column is equal to the value.
On columns with type converters, the filter operations invoked with
call or equals apply the type converter. This method will always
bypass any type converter that might be set on the column.
If value is null, the comparison evaluates to false.
Implementation
Expression<bool> sqlEquals(T? value) {
if (value == null) {
// A comparison to null should always be false here.
return $composableFilter(const Constant(false));
} else {
return $composableFilter(column.equals(value));
}
}