type property
The existing class
This type must refer to an existing class or a record structure. All other types, like functions or types with arguments, are not allowed.
Implementation
final Type type;
The existing class
This type must refer to an existing class or a record structure. All other types, like functions or types with arguments, are not allowed.
final Type type;