driftDatabase function
Implementation
QueryExecutor driftDatabase({
required String name,
bool logsEnabled = false,
}) {
return DatabaseConnection.delayed(Future(() async {
final result = await WasmDatabase.open(
databaseName: name,
sqlite3Uri: Uri.parse('sqlite3.wasm'),
driftWorkerUri: Uri.parse('drift_worker.js'),
);
if (result.missingFeatures.isNotEmpty) {
// Depending how central local persistence is to your app, you may want
// to show a warning to the user if only unrealiable implemetentations
// are available.
logger.e('Using ${result.chosenImplementation} due to missing browser '
'features: ${result.missingFeatures}');
}
return result.resolvedExecutor;
}));
}